@@ -48,6 +48,7 @@ DEVICE_READ_HCMAP = {
             ],
         ],
         "ambient_temp": [float, "A_216"],
+        "loop_type": [int, "I_62"],  # 0=none, 1=mix, 2=thermostatic, 3=hot water
         "pad": {
             "enabled": [bool, "D_245"],
             "state": [int, "I_15"],  # 0 - Permanently Off, 1 - Scheduled Off, 2 - On
@@ -86,8 +87,10 @@ DEVICE_READ_HCMAP = {
             ],
         ],
         "ambient_temp": [float, "A_222"],
+        "loop_type": [int, "I_65"],
         "pad": {
             "enabled": [bool, "D_248"],
+            "state": [bool, "I_6"],
             "current_humidity": [float, "I_220"],
         },
         "control_curve_heating": {
@@ -123,8 +126,10 @@ DEVICE_READ_HCMAP = {
             ],
         ],
         "ambient_temp": [float, "A_228"],
+        "loop_type": [int, "I_68"],
         "pad": {
             "enabled": [bool, "D_251"],
+            "state": [int, "I_227"],
             "current_humidity": [float, "I_221"],
         },
         "control_curve_heating": {
@@ -161,8 +166,10 @@ DEVICE_READ_HCMAP = {
             ],
         ],
         "ambient_temp": [float, "A_234"],
+        "loop_type": [int, "I_69"],
         "pad": {
             "enabled": [bool, "D_254"],
+            "state": [int, "I_230"],
             "current_humidity": [float, "I_222"],
         },
         "control_curve_heating": {
@@ -198,8 +205,10 @@ DEVICE_READ_HCMAP = {
             ],
         ],
         "ambient_temp": [float, "A_241"],
+        "loop_type": [int, "I_285"],
         "pad": {
             "enabled": [bool, "D_257"],
+            "state": [int, "I_239"],
             "current_humidity": [float, "I_223"],
         },
         "control_curve_heating": {
@@ -236,8 +245,10 @@ DEVICE_READ_HCMAP = {
             ],
         ],
         "ambient_temp": [float, "A_250"],
+        "loop_type": [int, "I_290"],
         "pad": {
             "enabled": [bool, "D_259"],
+            "state": [int, "I_210"],
             "current_humidity": [float, "I_224"],
         },
         "control_curve_heating": {
@@ -275,12 +286,37 @@ DEVICE_READ_HCMAP = {
 # used moving to main section so they don't get disabled
 # --------------------------------------------------------
 DEVICE_READ_MAP = {
+    "hp_type": [int, "I_14"],  # 0=A/W, 1=B/W, 2=W/W, 3=DX/W, 4=A/W R, 5=B/W R, 6=W/W R
     "hp_power_state": [bool, "D_3"],
     "hp_function": [int, "I_51"],  # 0: heating, #1: cooling, #2: auto (Write)
     "operating_mode": [
-        Special(str, Special.FIXED),
-        "heating",
-    ],  # heating, cooling, pool, dhw, dpc
+        Special(str, Special.FORMULA),
+        [
+            (
+                "'dhw' if {0} else "
+                "'pool' if {1} else "
+                "'aux_heater' if not ({2} or {3}) and ({4} or {5}) else "
+                "'dpc' if {6} else "
+                "'cooling' if {7} else "
+                "'heating' if {8} or {9} or {10} or {11} else "
+                "'idle'"
+            ),
+            [
+                [bool, "D_66"],  # 0 - domestic hot water
+                [bool, "D_43"],  # 1 - pool
+                [bool, "D_20"],  # 2 - some_error
+                [bool, "D_21"],  # 3 - three_errors
+                [bool, "D_6"],  # 4 - aux heater 1
+                [bool, "D_7"],  # 5 - aux heater 2
+                [bool, "D_196"],  # 6 - Dew Point
+                [bool, "D_4"],  # 7 - Cooling Mode
+                [bool, "D_5"],  # 8 - Compressor 1
+                [bool, "D_32"],  # 9 - Compressor 2
+                [bool, "D_10"],  # 10 - Ciculation
+                [bool, "D_8"],  # 11 - Fan
+            ],
+        ],
+    ],
     "season": {
         "mode": [
             Special(str, Special.FORMULA),
@@ -316,8 +352,9 @@ DEVICE_READ_MAP = {
         "outside_max": [float, "A_308"],
     },
     "domestic_hot_water": {
-        "heating": [bool, "D_66"],
         "enabled": [bool, "D_275"],
+        "state": [bool, "D_29"],
+        "heating": [bool, "D_66"],
         "current_temp": [float, "A_126"],
         "required_temp": [float, "A_129"],
         "min_temp": [float, "A_296"],
@@ -326,7 +363,8 @@ DEVICE_READ_MAP = {
     "compressor_running": [bool, "D_5"],
     "compressor2_running": [bool, "D_32"],
     "circulation_pump_running": [bool, "D_10"],
-    "fan_running": [bool, "D_8"],
+    "fan_running": [bool, "D_8"],  # Filtered by HP Type
+    "brine_pump_running": [bool, "D_8"],  # Filtered by HP Type,
     "defrost_mode": [bool, "D_11"],
     "aux_heater_1": [bool, "D_6"],
     "aux_heater_2": [bool, "D_7"],
@@ -349,8 +387,8 @@ DEVICE_READ_MAP = {
         "aux2_runtime": [int, "I_101"],
     },
     "error_info": {
-        "some_error": [bool, "D_20"],
-        "three_errors": [bool, "D_21"],
+        "some_error": [bool, "D_20"],  # Some Alarm has activated
+        "three_errors": [bool, "D_21"],  # 3 error conditions met, manual reset required
         "reset_3e": [bool, "D_19"],
         "safety_tstat": [bool, "D_77"],
         "alarm_a": [int, "I_20"],
