@@ -33,3 +33,18 @@ class MasterthermTokenInvalid(MasterthermError):
 
 class MasterthermUnsupportedRole(MasterthermError):
     """Raised when connecting to an Unsupported Role."""
+
+
+class MasterthermEntryNotFound(MasterthermError):
+    """Raised when the data entry update requested is not found."""
+
+
+class MasterthermPumpError(MasterthermError):
+    """Raised if there is an Error retrieving data from the pump."""
+
+    DEVICENOTFOUND = 5
+    OFFLINE = 9
+
+
+class MasterthermServerTimeoutError(MasterthermError):
+    """Raised if there is a server timeout error."""
